@@ -46,7 +46,7 @@ raw values read out
 """
 
 
-__version__ = '1.3.3'
+__version__ = '1.3.4'
 
 import serial
 import time
@@ -56,6 +56,7 @@ import json
 import signal
 import platform
 import serial.tools.list_ports as list_ports
+from collections import OrderedDict
 
 # Choices allowed for 'get' command
 choices_for_get = [
@@ -99,6 +100,38 @@ ser = None
 terminate = False
 
 
+def convert_json_to_csv(json_file, csv_file):
+    # Load JSON data in OrderedDict, to preserve current order
+    json_data = json.load(json_file, object_pairs_hook=OrderedDict)
+
+    # Print out the header based on JSON contents
+
+    # Compact Format
+    if "format" in json_data:
+        # Create header
+        for n, elem in enumerate(json_data['format']):
+            csv_file.write("{0}{1}".format('' if n == 0 else ',', elem))
+        csv_file.write('\n')
+
+        # Write out data
+        if "data" in json_data:
+            for elem in json_data['data']:
+                csv_file.write(','.join(map(str, elem)) + '\n')
+
+    # Non-compact format
+    else:
+        if "data" in json_data:
+            for n, (key, value) in enumerate(json_data['data'][0].items()):
+                csv_file.write("{0}{1}".format('' if n == 0 else ',', key))
+            csv_file.write('\n')
+
+            for row in json_data['data']:
+                for n, (key, value) in enumerate(row.items()):
+                    csv_file.write("{0}{1}".format(
+                        '' if n == 0 else ',', value))
+                csv_file.write('\n')
+
+
 def get_available_serial_ports():
     """Gets the available serial ports"""
     ports = [comport.device for comport in list_ports.comports()]
@@ -288,7 +321,7 @@ def cmd_log(args):
     if(args.use_cfg is not None):
         set_log_settings(args.use_cfg, verbose)
         # Wait some time for those settings to come into effect
-        time.sleep(5)
+        time.sleep(3)
 
     # Run through the dict getting our responses
     settings_resp = get_log_settings()
@@ -390,6 +423,11 @@ def cmd_log(args):
             (args.time != 0) and time.time() >= (start_time_offset + args.time)
         ):
             args.logfile.write("]}\n")
+            if(args.also_csv):
+                args.logfile.seek(0, 0)
+                with open(args.logfile.name[0:-4] + "csv", "w+") as csvfile:
+                    convert_json_to_csv(args.logfile, csvfile)
+
             args.logfile.close()
             if(not args.override_run):
                 set_mvm_param(ser, "run", 0)
@@ -423,7 +461,7 @@ def cmd_console_log(args):
 
         # Wait a bit and clear out the old settings
         time_to_poll = time.time()
-        while(time.time() < (time_to_poll + 5.0)):
+        while(time.time() < (time_to_poll + 3.0)):
             resp = ser.read_until().decode('utf-8').strip()
             time.sleep(0.01)
 
@@ -529,7 +567,14 @@ def cmd_console_log(args):
             # Turn off console logging
             set_mvm_param(ser, 'console', 0)
             args.logfile.write("]}\n")
+
+            if(args.also_csv):
+                args.logfile.seek(0, 0)
+                with open(args.logfile.name[0:-4] + "csv", "w+") as csvfile:
+                    convert_json_to_csv(args.logfile, csvfile)
+
             args.logfile.close()
+
             if(not args.override_run):
                 set_mvm_param(ser, "run", 0)
             print('')
@@ -539,6 +584,10 @@ def cmd_console_log(args):
         time.sleep(0.005)
 
 
+def cmd_convert(args):
+    convert_json_to_csv(args.jsonfile, args.csvfile)
+
+
 def cmd_load(args):
     """Command that loads the settings to the device"""
     set_log_settings(args.cfgfile)
@@ -582,6 +631,22 @@ def main():
             title='Subcommands',
             help='Commands available')
 
+        # Convert command
+        parser_convert = subparsers.add_parser(
+            'convert',
+            help='convert <jsonfile> <csvfile>',
+            usage="%(prog)s <jsonfile> <csvfile>"
+        )
+        parser_convert.add_argument(
+            'jsonfile',
+            type=argparse.FileType('r'),
+            help="JSON file to convert to CSV")
+        parser_convert.add_argument(
+            'csvfile',
+            type=argparse.FileType('w+'),
+            help="CSV file to create")
+        parser_convert.set_defaults(func=cmd_convert)
+
         # Get command
         parser_get = subparsers.add_parser(
             'get',
@@ -636,6 +701,11 @@ def main():
             'log',
             usage="%(prog)s [option] <file>",
             help="log [option] <file>")
+        parser_log.add_argument(
+            '-a',
+            '--also-csv',
+            action='store_true',
+            help='Also create CSV file')
         parser_log.add_argument(
             '-c',
             '--compact',
@@ -684,6 +754,11 @@ def main():
             '--compact',
             action='store_true',
             help="Generate compact log")
+        parser_clog.add_argument(
+            '-a',
+            '--also-csv',
+            action='store_true',
+            help='Also create CSV file')
         parser_clog.add_argument(
             '-o',
             '--override-run',
